include.block("RecExCond/RecExCommon_DetFlags.py")
from AthenaCommon.Logging import logging
logRecExCommon_DetFlags = logging.getLogger( 'RecExCommon_DetFlags' )

from RecExConfig.Resilience import treatException
# DetFlags : Author Tadashi Maeno
#
# detectors : ID = pixel SCT TRT
#             LAr = em HEC FCal 
#             Calo = em HEC FCal Tile
#             Muon = MDT CSC TGC RPC 
# tasks:
#   geometry : setup the geometry
#   simulate : simulate
#   simulateLVL1 : LVL1 simulation
#   detdescr : setup detector description (for anything which is not geant)
#   pileup   : collect hits from physics and min bias events
#   digitize : hit -> RDO (raw data objects)
#   makeRIO  : RDO -> RIO (Reconstruction Input Objects)
#   writeBS  : write RDO byte stream
#   readRDOBS : read RDO from byte stream
#   readRDOPool : read RDO from pool
#   readRIOBS : read RIO directly from BS
#   writeRDOPool : write RDO in pool
#   readRIOPool  : read RIO from pool
#   writeRIOPool : write RIO in pool
#
# Some tasks are OR of other tasks. They can only be used to test, not to set.
#  haveRDO = readRDOPool or readRDOBS
#  haveRIO = makeRIO or readRIOPool or readRIOBS
#
# subdetectors and tasks from a matrix of flags which are all
#    off by default
# changing the flags:
# tasks can be switched on/off for all detectors:
#    DetFlags.detdescr.all_setOn() (or all_setOff()
# a task for a given subdetector can be switched on/off
#    DetFlags.readRDOPool.Pixel_setOn() (or setOff() )
# setting off/on a group of subdetectors (e.g. LAr or Muon) switch off/on
#     all the corresponding subdetectors
# a subdetector can be switched on/off for all tasks:
#       DetFlags.Muon_setOn() (or setOff() )
#
# Flags can be tested individually:
# if DetFlags.detdescr.pixel_on():
#    print "pix Geo On"
# else:
#    print "pix Geo Off"    
# there is no off() method, just use not
# Group of subdetectors can also be tested: 
# if DetFlags.detdescr.any_on() : true if any subdet is true
# if DetFlags.detdescr.allOn() : true if all subdet is true
# if DetFlags.detdescr.LAr_on() : true if any LAr det is true
# if DetFlags.detdescr.LAr_allOn() : true if all LAr det is true 
# if DetFlags.haveRIO.Calo_on() : true if any Calo RIO are present (made or read from file) 
if 'DetFlags' in dir():
   logRecExCommon_DetFlags.info("DetFlags already defined.by user : user should have fully configured it already! ")
else:
   
   include ("RecExCond/RecExCommon_GlobalFlags.py")

   # include DetFlags
   # by default everything is off
   from AthenaCommon.DetFlags import DetFlags
   # switch on tasks for all detectors
   DetFlags.detdescr.all_setOn()


   from RecExConfig.RecFlags  import rec
   if  not rec.readESD() and not rec.readAOD() and not rec.doWriteRDO() :
      DetFlags.makeRIO.all_setOn()
   else:
      DetFlags.makeRIO.all_setOff()
      #calo cells are there on ESD
      if rec.readESD() :
         DetFlags.readRIOPool.Calo_setOn()
         DetFlags.readRIOPool.ID_setOn()
         DetFlags.makeRIO.ID_setOn()
         DetFlags.readRIOPool.Muon_setOn()
         
   if rec.readRDO:      
      if  globalflags.InputFormat=='pool':
         DetFlags.readRDOPool.all_setOn()
         DetFlags.readRDOBS.all_setOff()
         DetFlags.readRIOBS.all_setOff()
      elif globalflags.InputFormat=='bytestream':
         DetFlags.readRDOPool.all_setOff()
         DetFlags.readRDOBS.all_setOn()
   else:
      DetFlags.readRDOPool.all_setOff()
      DetFlags.readRDOBS.all_setOff()


   if 'readMuonDigit' in dir() and readMuonDigit:
   # very special case for normal Rome production
      DetFlags.readRDOPool.Muon_setOff()
      DetFlags.readRIOPool.Muon_setOn()
      if not ('doWriteRDO' in dir() and  doWriteRDO) :
         DetFlags.makeRIO.Muon_setOn()

   # switch off lucid stuff for now     
   DetFlags.Lucid_setOff()   

#synch muon flags to detflags
try:
   from MuonRecExample.MuonRecFlags import muonRecFlags
   muonRecFlags.sync_DetFlags()
except Exception:
   treatException ("Could not synch DetFlags to muonRecFlags")
